@@ -1,14 +1,17 @@
 package WordList::Test::Dynamic::Number::10Million;
 
-our $DATE = '2021-02-23'; # DATE
-our $VERSION = '0.004'; # VERSION
-
+use strict;
 use WordList;
 our @ISA = qw(WordList);
 
 use Role::Tiny::With;
 with 'WordListRole::EachFromFirstNextReset';
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-12-01'; # DATE
+our $DIST = 'WordList-Test-Dynamic-Number-10Million'; # DIST
+our $VERSION = '0.005'; # VERSION
+
 our $DYNAMIC = 1;
 
 sub reset_iterator {
@@ -23,14 +26,14 @@ sub first_word {
 }
 
 sub next_word {
-    my $self = @_;
+    my $self = shift;
 
     $self->{_iterator_idx} = 0 unless defined $self->{_iterator_idx};
-    return undef if $self->{_iterator_idx}++ >= 10_000_000;
+    return undef if $self->{_iterator_idx}++ >= 10_000_000; ## no critic: Subroutines::ProhibitExplicitReturnUndef
     sprintf "%08d", $self->{_iterator_idx};
 }
 
-our %STATS = ("num_words_contains_nonword_chars",0,"longest_word_len",8,"avg_word_len",8,"shortest_word_len",8,"num_words_contain_unicode",0,"num_words_contains_whitespace",0,"num_words_contains_unicode",0,"num_words",10000000,"num_words_contain_whitespace",0,"num_words_contain_nonword_chars",0); # STATS
+our %STATS = ("num_words_contains_unicode",0,"num_words",10000000,"longest_word_len",8,"num_words_contains_nonword_chars",0,"num_words_contains_whitespace",0,"num_words_contain_whitespace",0,"shortest_word_len",8,"num_words_contain_unicode",0,"num_words_contain_nonword_chars",0,"avg_word_len",8); # STATS
 
 1;
 # ABSTRACT: 10 million numbers from "00000001" to "10000000"
@@ -47,7 +50,7 @@ WordList::Test::Dynamic::Number::10Million - 10 million numbers from "00000001"
 
 =head1 VERSION
 
-This document describes version 0.004 of WordList::Test::Dynamic::Number::10Million (from Perl distribution WordList-Test-Dynamic-Number-10Million), released on 2021-02-23.
+This document describes version 0.005 of WordList::Test::Dynamic::Number::10Million (from Perl distribution WordList-Test-Dynamic-Number-10Million), released on 2021-12-01.
 
 =head1 SYNOPSIS
 
@@ -56,11 +59,12 @@ This document describes version 0.004 of WordList::Test::Dynamic::Number::10Mill
  my $wl = WordList::Test::Dynamic::Number::10Million->new;
 
  # Pick a (or several) random word(s) from the list
- my $word = $wl->pick;
- my @words = $wl->pick(3);
+ my ($word) = $wl->pick;
+ my ($word) = $wl->pick(1);  # ditto
+ my @words  = $wl->pick(3);  # no duplicates
 
  # Check if a word exists in the list
- if ($wl->word_exists('foo')) { ... }
+ if ($wl->word_exists('foo')) { ... }  # case-sensitive
 
  # Call a callback for each word
  $wl->each_word(sub { my $word = shift; ... });
@@ -69,7 +73,7 @@ This document describes version 0.004 of WordList::Test::Dynamic::Number::10Mill
  my $first_word = $wl->first_word;
  while (defined(my $word = $wl->next_word)) { ... }
 
- # Get all the words
+ # Get all the words (beware, some wordlists are *huge*)
  my @all_words = $wl->all_words;
 
 =head1 WORDLIST STATISTICS
@@ -99,23 +103,40 @@ Please visit the project's homepage at L<https://metacpan.org/release/WordList-T
 
 Source repository is at L<https://github.com/perlancar/perl-WordList-Test-Dynamic-Number-10Million>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2021, 2020, 2018 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-WordList-Test-Dynamic-Number-10Million/issues>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=WordList-Test-Dynamic-Number-10Million>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021, 2020, 2018 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
